Documentation
¶
Overview ¶
Package options contains flags and options for initializing an apiserver
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddCustomGlobalFlags ¶
AddCustomGlobalFlags explicitly registers flags that internal packages register against the global flagsets from "flag". We do this in order to prevent unwanted flags from leaking into the kube-apiserver's flagset.
Types ¶
type CompletedOptions ¶
type CompletedOptions struct {
// contains filtered or unexported fields
}
func (CompletedOptions) Validate ¶
func (o CompletedOptions) Validate() []error
Validate checks ServerRunOptions and return a slice of found errs.
type Extra ¶
type Extra struct {
MasterCount int
// In the future, perhaps an "onexlet" will be added, similar to the "kubelet".
// OnexletConfig onexletclient.OnexletClientConfig
APIServerServiceIP net.IP
EndpointReconcilerType string
// For external resources
ExternalRESTStorageProviders []storage.RESTStorageProvider
ExternalPostStartHooks map[string]genericapiserver.PostStartHookFunc
GetOpenAPIDefinitions common.GetOpenAPIDefinitions
}
type ServerRunOptions ¶
type ServerRunOptions struct {
*controlplaneoptions.Options
Extra
}
ServerRunOptions contains state for master/api server.
func NewServerRunOptions ¶
func NewServerRunOptions() *ServerRunOptions
NewServerRunOptions returns a new ServerRunOptions.
func (*ServerRunOptions) Complete ¶
func (o *ServerRunOptions) Complete() (CompletedOptions, error)
Complete set default ServerRunOptions. Should be called after onex-apiserver flags parsed.
func (ServerRunOptions) Flags ¶
func (o ServerRunOptions) Flags() (fss cliflag.NamedFlagSets)
Click to show internal directories.
Click to hide internal directories.